""" Plugin entry point for helga """
import re

import requests
from amazon.api import AmazonAPI

from helga import settings
from helga.plugins import match


PRODUCT_REGEX = r'amazon\.com/(?:[\w|-]+/)?dp/(\w+)'
SHORT_REGEX = r'(a.co/\w+)'


@match(PRODUCT_REGEX)
def amazon_meta(client, channel, nick, message, match):
    return generate_amazon_response(match)


@match(SHORT_REGEX)
def amazon_meta_short(client, channel, nick, message, match):
    return handle_short_link(match)


def handle_short_link(url):
    response = requests.get('http://' + url)
    url = response.url
    match = re.search(PRODUCT_REGEX, url)
    product_id = match.group(1)
    return generate_amazon_response(product_id)


def generate_amazon_response(product_id):
    if not settings.AMAZON_ACCESS_KEY or not settings.AMAZON_SECRET_KEY or not settings.AMAZON_ASSOC_TAG:
        return 'Amazon API keys not set, please add to your settings'
    amazon = AmazonAPI(settings.AMAZON_ACCESS_KEY, settings.AMAZON_SECRET_KEY, settings.AMAZON_ASSOC_TAG)
    product = amazon.lookup(ItemId=match)
    return 'Title: {} Price: {}'.format(product.title, product.price)



import re
import sys
from unittest import TestCase
try:
    from unittest import mock
except ImportError:
    from mock import mock
sys.modules['helga.plugins'] = mock.Mock()

from helga_amazon_meta.plugin import PRODUCT_REGEX, SHORT_REGEX


class TestPlugin(TestCase):
    def test_product_regex(self):
        regex = re.compile(PRODUCT_REGEX)
        expected = 'ABCD0123456'
        product_url = 'amazon.com/product_description/dp/' + expected
        result = re.search(regex, product_url)
        self.assertEqual(expected, result.group(1))

    def test_product_short(self):
        regex = re.compile(SHORT_REGEX)
        expected = 'a.co/c5aX6WD'
        product_url = 'http://' + expected
        result = re.search(regex, product_url)
        self.assertEqual(expected, result.group(1))



from setuptools import setup, find_packages
from helga_amazon_meta import __version__ as version


setup(
    name='helga-amazon-meta',
    version=version,
    description=('Provide information for related metadata'),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Topic :: Communications :: Chat :: Internet Relay Chat',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Communications :: Chat :: Internet Relay Chat'],
    keywords='irc bot amazon-meta',
    author='Jon Robison',
    author_email='narfman0@gmail.com',
    url='https://github.com/narfman0/helga-amazon-meta',
    license='LICENSE',
    packages=find_packages(),
    include_package_data=True,
    py_modules=['helga_amazon_meta.plugin'],
    zip_safe=True,
    install_requires=[
        'helga',
        'python-amazon-simple-product-api',
        'requests',
    ],
    test_suite='',
    entry_points=dict(
        helga_plugins=[
            'amazon-meta = helga_amazon_meta.plugin:amazon_meta',
            'amazon-meta-short = helga_amazon_meta.plugin:amazon_meta_short',
        ],
    ),
)
